@@ -10,8 +10,8 @@ use strict;
 
 ########################################################
 # Specify version and build-date:
-my $Version = '7.5.3';
-my $VDate = '01/22/20';
+my $Version = '7.5.4';
+my $VDate = '07/22/20';
 
 #######################################################
 # Logwatch was originally written by:
@@ -987,7 +987,8 @@ sub getInt {
 sub CleanVars {
    foreach (keys %Config) {
       unless (defined $Config{$_} and
-	($_ =~ /^(hostname|filename|mailto|logdir|hostlimit)$/ )) {
+	# For the following config keys, do not make any changes to value
+	($_ =~ /^(hostname|filename|mailto|logdir|hostlimit|mailer)$/ )) {
          $Config{$_} = getInt($Config{$_});
       }
    }
